@@ -9,6 +9,7 @@ class TestBronze:
                  storage_silver, input_data_param, input_data_param_v1, input_data_param_v2, input_data_param_v3,
                  colums_validate_merge_param, new_name, database, target, origin, colum_filter, value_filter,
                  colum_validate_data, value_validate_data):
+        self.util = Util()
         self.colum_filter = colum_filter
         self.value_filter = value_filter
         self.colum_validate_data = colum_validate_data
@@ -58,6 +59,6 @@ class TestBronze:
         assert value[0][self.colum_validate_data] == self.value_validate_data
         self.delta_lake_v1.spark.sql("DROP TABLE {0}.{1}".format(self.delta_lake_v1.database,
                                                                  self.delta_lake_v1.table_name))
-        list_file = Util.list_folder_delta_lake(self.delta_lake_v1.mount_data)
+        list_file = self.util.list_folder_delta_lake(self.delta_lake_v1.mount_data)
         for item in list_file:
-            Util.delete_file_delta_lake(item.path)
+            self.util.delete_file_delta_lake(item.path)
